@@ -1,8 +1,8 @@
 #' Daily Value USGS NWIS Data Retrieval
 #'
-#' Imports data from NWIS web service. This function gets the data from here: \url{http://waterservices.usgs.gov/}
+#' Imports data from NWIS web service. This function gets the data from here: \url{https://waterservices.usgs.gov/}
 #'
-#' @param siteNumber character USGS site number.  This is usually an 8 digit number. Multiple sites can be requested with a character vector.
+#' @param siteNumbers character USGS site number.  This is usually an 8 digit number. Multiple sites can be requested with a character vector.
 #' @param parameterCd character of USGS parameter code(s).  This is usually an 5 digit number.
 #' @param startDate character starting date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates
 #' retrieval for the earliest possible record. Date arguments are always specified in local time.
@@ -35,16 +35,17 @@
 #' }
 #' 
 #' @seealso \code{\link{renameNWISColumns}}, \code{\link{importWaterML1}}
+#' @importFrom lubridate parse_date_time
 #' @export
 #' @keywords data import USGS web service
 #' @examples
-#' siteNumber <- '04085427'
+#' site_id <- '04085427'
 #' startDate <- '2012-01-01'
 #' endDate <- '2012-06-30'
 #' pCode <- '00060'
 #' \dontrun{
-#' rawDailyQ <- readNWISdv(siteNumber,pCode, startDate, endDate)
-#' rawDailyQAndTempMeanMax <- readNWISdv(siteNumber,c('00010','00060'),
+#' rawDailyQ <- readNWISdv(site_id,pCode, startDate, endDate)
+#' rawDailyQAndTempMeanMax <- readNWISdv(site_id,c('00010','00060'),
 #'        startDate, endDate, statCd=c('00001','00003'))
 #' rawDailyQAndTempMeanMax <- renameNWISColumns(rawDailyQAndTempMeanMax)
 #' rawDailyMultiSites<- readNWISdv(c("01491000","01645000"),c('00010','00060'),
@@ -58,9 +59,9 @@
 #' site <- "05212700"
 #' notActive <- readNWISdv(site, "00060", "2014-01-01","2014-01-07")
 #' }
-readNWISdv <- function (siteNumber,parameterCd,startDate="",endDate="",statCd="00003"){  
+readNWISdv <- function (siteNumbers,parameterCd,startDate="",endDate="",statCd="00003"){  
   
-  url <- constructNWISURL(siteNumber,parameterCd,startDate,endDate,"dv",statCd=statCd)
+  url <- constructNWISURL(siteNumbers,parameterCd,startDate,endDate,"dv",statCd=statCd)
 
   data <- importWaterML1(url, asDateTime=FALSE)
   if(nrow(data)>0){
